package com.ruoyi.system.service.impl.fgw;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.fgw.FgwYjpzMapper;
import com.ruoyi.system.domain.fgw.FgwYjpz;
import com.ruoyi.system.service.fgw.IFgwYjpzService;

/**
 * 发改委_预警配置Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-03-30
 */
@Service
public class FgwYjpzServiceImpl implements IFgwYjpzService 
{
    @Autowired
    private FgwYjpzMapper fgwYjpzMapper;

    /**
     * 查询发改委_预警配置
     * 
     * @param id 发改委_预警配置主键
     * @return 发改委_预警配置
     */
    @Override
    public FgwYjpz selectFgwYjpzById(Long id)
    {
        return fgwYjpzMapper.selectFgwYjpzById(id);
    }

    /**
     * 查询发改委_预警配置列表
     * 
     * @param fgwYjpz 发改委_预警配置
     * @return 发改委_预警配置
     */
    @Override
    public List<FgwYjpz> selectFgwYjpzList(FgwYjpz fgwYjpz)
    {
        return fgwYjpzMapper.selectFgwYjpzList(fgwYjpz);
    }

    /**
     * 新增发改委_预警配置
     * 
     * @param fgwYjpz 发改委_预警配置
     * @return 结果
     */
    @Override
    public int insertFgwYjpz(FgwYjpz fgwYjpz)
    {
        fgwYjpz.setCreateTime(DateUtils.getNowDate());
        fgwYjpz.setUpdateTime(DateUtils.getNowDate());
        return fgwYjpzMapper.insertFgwYjpz(fgwYjpz);
    }

    /**
     * 修改发改委_预警配置
     * 
     * @param fgwYjpz 发改委_预警配置
     * @return 结果
     */
    @Override
    public int updateFgwYjpz(FgwYjpz fgwYjpz)
    {
        fgwYjpz.setUpdateTime(DateUtils.getNowDate());
        return fgwYjpzMapper.updateFgwYjpz(fgwYjpz);
    }

    /**
     * 批量删除发改委_预警配置
     * 
     * @param ids 需要删除的发改委_预警配置主键
     * @return 结果
     */
    @Override
    public int deleteFgwYjpzByIds(Long[] ids)
    {
        return fgwYjpzMapper.deleteFgwYjpzByIds(ids);
    }

    /**
     * 删除发改委_预警配置信息
     * 
     * @param id 发改委_预警配置主键
     * @return 结果
     */
    @Override
    public int deleteFgwYjpzById(Long id)
    {
        return fgwYjpzMapper.deleteFgwYjpzById(id);
    }
}
